require 'uu/applog/application_log/time_conversions'
require 'uu/os/rest/dto'

module UU
  module AppLog
    module ApplicationLog

      # DTO containing criteria limiting and ordering list of application log records.
      class ApplicationLogGetRecordList < UU::OS::REST::DTO
        include TimeConversions

        # Oldest time of time interval to get application log records for. When nil is
        # set, time 24 hours ago is assumed.
        # @param [String, DateTime, Time]
        # @return [String]
        attr_accessor :time_from

        # Newest time of time interval to get application log records for. When nil is
        # set, current time is assumed.
        # @param [String, DateTime, Time]
        # @return [String]
        attr_accessor :time_to

        # Index of first item of the returned list. It is useful for return more than in limit defined records split in time.
        # Offset means skip specified number of records and return next number of records until specified limit.
        # When nil is set, the first record is determined automatically.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :offset

        # Count of application log records to return at once. When no limit is specified,
        # 1000 records are returned at most. 1000 is also the largest limit number
        # that can be specified.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :limit

        def time_from
          attributes[:timeFrom]
        end

        def time_from=(val)
          attributes[:timeFrom] = to_iso8601(val)
        end

        def time_to
          attributes[:timeTo]
        end

        def time_to=(val)
          attributes[:timeTo] = to_iso8601(val)
        end

        def offset
          attributes[:offset]
        end

        def offset=(val)
          attributes[:offset] = val
        end

        def limit
          attributes[:limit]
        end

        def limit=(val)
          attributes[:limit] = val
        end
      end
    end
  end
end

